OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Tasks" : "Задачи",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} креираше календар {calendar}",
    "You created calendar {calendar}" : "Креиравте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} избриша календар {calendar}",
    "You deleted calendar {calendar}" : "Избришавте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ажурираше календар {calendar}",
    "You updated calendar {calendar}" : "Ажуриравте календар {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} врати календар {calendar}",
    "You restored calendar {calendar}" : "Вративте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Споделивте календар {calendar} како јавен линк",
    "You removed public link for calendar {calendar}" : "Отстранивте јавен линк за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} сподели календар {calendar} со вас",
    "You shared calendar {calendar} with {user}" : "Споделивте календар {calendar} со {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} сподели календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} отстрани споделување на календар {calendar} со вас",
    "You unshared calendar {calendar} from {user}" : "Отстранивте споделување на календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} отстрани споделување на календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} отстрани споделување на календар {calendar} со сите",
    "You shared calendar {calendar} with group {group}" : "Споделивте календар {calendar} со група {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} сподели календар {calendar} со група {group}",
    "You unshared calendar {calendar} from group {group}" : "Отстранивте споделување на календар {calendar} од група {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} отстрани споделување на календар {calendar} од група {group}",
    "Untitled event" : "Неименуван настан",
    "{actor} created event {event} in calendar {calendar}" : "{actor} креираше настан {event} во календар {calendar}",
    "You created event {event} in calendar {calendar}" : "Креиравте настан {event} во календар {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} избриша настан {event} од календар {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Избришавте настан {event} од календар {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ажурираше настан {event} во календар {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажуриравте настан {event} во календар {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} премести настан {event} од календар {sourceCalendar} во календар {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Преместивте настан {event} од календар {sourceCalendar} во календар {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} врати настан {event} во календарот {calendar}",
    "You restored event {event} of calendar {calendar}" : "Вративте настан {event} во календарот {calendar}",
    "Busy" : "Зафатен",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} креираше задолжение {todo} во листата {calendar}",
    "You created to-do {todo} in list {calendar}" : "Креиравте задолжение {todo} во листата {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} избриша задолжение {todo} од листата {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Избришавте задолжение {todo} од листата {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} ажурираше задолжение {todo} во листата {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Ажуриравте задолжение {todo} во листата {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} го заврши задолжението {todo} во листата {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Го завршивте задолжението {todo} во листата {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} повторно го отвори задолжението {todo} во листата {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Повторно го отворивте задолжението {todo} во листата {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} премести задолжение {todo} од листа {sourceCalendar} во листа {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Преместивте задолжение {todo} од листа {sourceCalendar} во листа {targetCalendar}",
    "Calendar, contacts and tasks" : "Календар, контакти и задачи",
    "A <strong>calendar</strong> was modified" : "<strong>Календарот</strong> е променет",
    "A calendar <strong>event</strong> was modified" : "Изменет е <strong>настан</strong> во календарот",
    "A calendar <strong>to-do</strong> was modified" : "Изменета е <strong>задача</strong> во календарот",
    "Contact birthdays" : "Родендени на контактите",
    "Death of %s" : "Смрт на %s",
    "Untitled calendar" : "Неименуван календар",
    "Calendar:" : "Календар:",
    "Date:" : "Датум:",
    "Where:" : "Каде: ",
    "Description:" : "Опис:",
    "_%n year_::_%n years_" : ["%n година","%n години"],
    "_%n month_::_%n months_" : ["%n месец","%n месеци"],
    "_%n day_::_%n days_" : ["%n ден","%n дена"],
    "_%n hour_::_%n hours_" : ["%n час","%n часа"],
    "_%n minute_::_%n minutes_" : ["%n минута","%n минути"],
    "%s (in %s)" : "%s (во %s)",
    "%s (%s ago)" : "%s (пред %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Датум: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Каде: %s",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "Cancelled: %1$s" : "Откажано: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" е отакажана",
    "Re: %1$s" : "Одг: %1$s",
    "%1$s has accepted your invitation" : "%1$s ја прифати вашата покана",
    "%1$s has tentatively accepted your invitation" : "%1$s привремено ја прифати нафаша покана",
    "%1$s has declined your invitation" : "%1$s ја одби вашата покана",
    "%1$s has responded to your invitation" : "%1$s одговори на вашата покана",
    "Invitation updated: %1$s" : "Поканата е ажурирана: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s го ажурираше настанот \"%2$s\"",
    "Invitation: %1$s" : "Покана: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s сака да те покани во \"%2$s\"",
    "Organizer:" : "Организатор:",
    "Attendees:" : "Присутни:",
    "Title:" : "Наслов:",
    "When:" : "Кога:",
    "Location:" : "Локација:",
    "Link:" : "Линк:",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "More options …" : "Повеќе опции ...",
    "More options at %s" : "Повеќе опции на %s",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sunday" : "Недела",
    "January" : "Јануари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јуни",
    "July" : "Јули",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "First" : "Прва",
    "Last" : "Последна",
    "Contacts" : "Контакти",
    "{actor} created address book {addressbook}" : "{actor} креираше адресар {addressbook}",
    "You created address book {addressbook}" : "Креиравте адресар {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} избриша адресар {addressbook}",
    "You deleted address book {addressbook}" : "Избришавте адресар {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ажурирање адресар {addressbook}",
    "You updated address book {addressbook}" : "Ажуриравте {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} сподели адресар {addressbook} со вас",
    "You shared address book {addressbook} with {user}" : "Споделивте адресар {addressbook} со {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} сподели адресар {addressbook} со {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} не го споделува адресар {addressbook} со вас",
    "You unshared address book {addressbook} from {user}" : "Не го споделиувате адресар {addressbook} со {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} не го споделува адресар {addressbook} со {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} не го споделува адресар {addressbook} со себе",
    "You shared address book {addressbook} with group {group}" : "Споделивте адресар {addressbook} со група {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} сподели адресар {addressbook} со група {group}",
    "You unshared address book {addressbook} from group {group}" : "Отстранивте од споделување адресар {addressbook} со група{group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} отстрани од споделување адресар {addressbook} од група {group}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Контракт</strong> или <strong>адресар</strong> е променет",
    "Accounts" : "Сметки",
    "System address book which holds all accounts" : "Системски адресар кој ги содржи сите сметки",
    "File is not updatable: %1$s" : "Датотека што не се ажурира: %1$s",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
    "Failed to open file: %1$s" : "Неуспешно отварање на датотека: %1$s",
    "File not found: %1$s" : "Датотеката не е пронајдена: %1$s",
    "System is in maintenance mode." : "Системот е во мод за одржување.",
    "Upgrade needed" : "Потребна е надградба",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Вашиот %s треба да биде конфигуриран за да користи HTTPS за да може да се користи CalDAV и CardDAV на iOS/macOS.",
    "Configures a CalDAV account" : "Конфигурирај CalDAV сметка",
    "Configures a CardDAV account" : "Конфигурирај CardDAV сметка",
    "Events" : "Настани",
    "Untitled task" : "Неименувана задача",
    "Completed on %s" : "Завршена на %s",
    "Due on %s by %s" : "Истекува на %s од %s",
    "Due on %s" : "Истекува на %s",
    "WebDAV endpoint" : "WebDAV крајна точка",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашиот веб опслужувач сеуште не е точно подесен да овозможува синхронизација на датотеки бидејќи интерфејсот за WebDAV изгледа дека е расипан. ",
    "Migrated calendar (%1$s)" : "мигриран календар (%1$s)",
    "Calendars including events, details and attendees" : "Календари вклучувајќи настани, детали и присутни",
    "Contacts and groups" : "Контакти и групи",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Отсуството е зачувано",
    "Failed to save your absence settings" : "Неуспешно зачувување на поставките за отсуство",
    "Absence cleared" : "Отсуството е избришано",
    "Failed to clear your absence settings" : "Неуспешно бришење на поставките за отсуство",
    "First day" : "Прв ден",
    "Last day (inclusive)" : "Последен ден (вклучително)",
    "Out of office replacement (optional)" : "Замена надвор од канцеларија (опционално)",
    "Name of the replacement" : "Има на замената",
    "No results." : "Нема резултати.",
    "Start typing." : "Започни со пишување.",
    "Short absence status" : "Статус на кратко отсуство",
    "Long absence Message" : "Порака за долго отсуство",
    "Save" : "Зачувај",
    "Disable absence" : "Оневозможи отсуство",
    "Failed to load availability" : "Неуспешно вчитување на достапноста",
    "Saved availability" : "Достапноста е зачувана",
    "Failed to save availability" : "Неуспешно зачувување на достапноста",
    "to" : "до",
    "Delete slot" : "Избриши слот",
    "No working hours set" : "Не се поставени работни часови",
    "Add slot" : "Додади слот",
    "Weekdays" : "Работни денови",
    "Pick a start time for {dayName}" : "Избери почетно време за {dayName}",
    "Pick a end time for {dayName}" : "Избери крајно време за {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматско поставување на статус во \"Не вознемирувај\" недостапен за да ги занемите сите известувања.",
    "Cancel" : "Откажи",
    "Import" : "Увези",
    "Reset to default" : "Ресетирај на стандардно",
    "Availability" : "Достапност",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ако ги поставите работните часови, другите корисници ќе можат да видат кога сте слободни за да можат да закажат состанок.",
    "Absence" : "Отсуство",
    "Configure your next absence period." : "Поставете го вашиот следен период на отсуство.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Исто така инсталирајте ја {calendarappstoreopen}Календар апликацијата{linkclose}, или {calendardocopen}поврзете го вашиот компјутер & мобилен за синхронизација ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Бидете сигурни дека правилно се поставени {emailopen}параметрите за Е-пошта{linkclose}.",
    "Calendar server" : "Календар сервер",
    "Send invitations to attendees" : "Испрати покани на учесниците",
    "Automatically generate a birthday calendar" : "Автоматско генерирање на календар со родендени",
    "Birthday calendars will be generated by a background job." : "Календарот со родендени ќе се генерира преку задачите што се извршуваат во позадина.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Оттука, тие нема да бидат достапни веднаш по овозможувањето, но ќе се појават по некое време.",
    "Send notifications for events" : "Испрати известувања за настани",
    "Notifications are sent via background jobs, so these must occur often enough." : "Известувањата ќе бидат испраќани преку задачите што се извршуваат во позадина, така што тие треба да се случуваат доволно често.",
    "Send reminder notifications to calendar sharees as well" : "Испратете известувања за потсетници и до споделувањата на календарот",
    "Reminders are always sent to organizers and attendees." : "Секогаш се испраќаат потсетници до организаторите и до присутните.",
    "Enable notifications for events via push" : "Овозможи известувања за настани преку push",
    "There was an error updating your attendance status." : "Настана грешка при ажурирање на вашето присуство.",
    "Please contact the organizer directly." : "Контактирајте го организаторот директно.",
    "Are you accepting the invitation?" : "Дали ја прифаќате поканата?",
    "Tentative" : "Прелиминарно",
    "Your attendance was updated successfully." : "Вашето присуство е успешно ажурирано.",
    "Time zone:" : "Временска зона:"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
